@@ -77,7 +77,7 @@ static void gppd_request_completed (GnomePilotClient* client,
 				    gpointer user_data);
 static void gppd_userinfo_requested (GnomePilotClient *gpc, 
 				     const gchar *device, 
-				     const GNOME_Pilot_PilotUser *user, 
+				     const GNOME_Pilot_UserInfo *user, 
 				     gpointer user_data);
 static void gppd_system_info_requested (GnomePilotClient *gpc,
 					const gchar *device,
@@ -295,17 +295,23 @@ gppd_request_completed (GnomePilotClient* client,
 	
 	priv = gppd->priv;
 
-	if (handle != priv->handle1)
+	if (handle == priv->handle1)
+		priv->handle1 = -1;
+	else if (handle == priv->handle2)
+		priv->handle2 = -1;
+	else
 		return;
 
-	gtk_widget_destroy (priv->sync_dialog);
-	priv->sync_dialog = NULL;
+	if (priv->handle1 == -1 && priv->handle2 == -1) {
+		gtk_widget_destroy (priv->sync_dialog);
+		priv->sync_dialog = NULL;
+	}
 }
 
 static void 
 gppd_userinfo_requested (GnomePilotClient *gpc, 
 			 const gchar *device, 
-			 const GNOME_Pilot_PilotUser *user, 
+			 const GNOME_Pilot_UserInfo *user, 
 			 gpointer user_data) 
 {
 	GnomePilotPDialog *gppd = GNOME_PILOT_PDIALOG (user_data);
@@ -323,12 +329,6 @@ gppd_userinfo_requested (GnomePilotClient *gpc,
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_username), priv->pilot->pilot_username);
 	g_snprintf (buf, sizeof (buf), "%d", priv->pilot->pilot_id);
 	gtk_entry_set_text (GTK_ENTRY (priv->pilot_id), buf);
-
-	priv->handle1 = -1;
-	priv->handle2 = -1;
-
-	gtk_widget_destroy (priv->sync_dialog);
-	priv->sync_dialog = NULL;
 }
 
 static void 
@@ -344,12 +344,6 @@ gppd_system_info_requested (GnomePilotClient *gpc,
 	
 	priv->pilot->creation = sysinfo->creation;
 	priv->pilot->romversion = sysinfo->romVersion;
-
-       	priv->handle1 = -1;
-	priv->handle2 = -1;
-
-	gtk_widget_destroy (priv->sync_dialog);
-	priv->sync_dialog = NULL;
 }
 
 
@@ -425,7 +419,7 @@ gppd_pilot_send (GtkWidget *widget, gpointer user_data)
 {
 	GnomePilotPDialog *gppd = GNOME_PILOT_PDIALOG (user_data);
 	GnomePilotPDialogPrivate *priv;
-	GNOME_Pilot_PilotUser user;
+	GNOME_Pilot_UserInfo user;
 	GPilotPilot *pilot;
 	GPilotDevice *dev;
 
