@@ -70,8 +70,8 @@ copyPilotState (PilotState *dest, PilotState *src)
 {
     dest->syncPCid = src->syncPCid;
     dest->progress_stepping = src->progress_stepping;
-    g_list_foreach (src->pilots,(GFunc)copy_pilot, dest);
-    g_list_foreach (src->devices,(GFunc)copy_device, dest);
+    if (src->pilots) g_list_foreach (src->pilots,(GFunc)copy_pilot, dest);
+    if (src->devices) g_list_foreach (src->devices,(GFunc)copy_device, dest);
 }
 
 PilotState*
@@ -126,7 +126,7 @@ loadDeviceCfg (PilotState *p)
   gnome_config_pop_prefix ();
 
   if (num == 0) {
-	  g_message ("No pilot craddle information located");
+	  g_message ("No pilot cradle information located");
 	  p->devices = NULL;
 	  return -1;
   } else {
@@ -254,7 +254,7 @@ loadPilotState (PilotState **pilotState)
     }
 
     if (loadDeviceCfg (p) < 0) {
-	g_message ("Unable to load pilot craddle info, assuming unset");
+	g_message ("Unable to load pilot cradle info, assuming unset");
     }
 
     *pilotState = p;
@@ -353,6 +353,8 @@ load_conduit_list (GPilotPilot *pilot)
 		conduit_state->pilot = pilot;
 		conduit_state->management = gnome_pilot_conduit_management_new (conduit_state->name, GNOME_PILOT_CONDUIT_MGMT_NAME);
 		conduit_state->config = gnome_pilot_conduit_config_new (conduit_state->management, pilot->pilot_id);
+		gnome_pilot_conduit_config_load_config (conduit_state->config);
+
 		conduit_state->description = g_strdup ((gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "description", NULL));
 		conduit_state->icon = g_strdup ((gchar*)gnome_pilot_conduit_management_get_attribute (conduit_state->management, "icon", NULL));
 		if (conduit_state->icon == NULL || g_file_test (conduit_state->icon, G_FILE_TEST_ISFILE)==FALSE) {
@@ -377,9 +379,11 @@ load_conduit_list (GPilotPilot *pilot)
 			conduit_state->orig_sync_type = conduit_state->sync_type;
 		else 
 			conduit_state->orig_sync_type = GnomePilotConduitSyncTypeNotSet;
+		conduit_state->first_sync_type = conduit_state->config->first_sync_type;
+		conduit_state->orig_first_sync_type = conduit_state->first_sync_type;
 		conduit_states = g_list_append (conduit_states, conduit_state);
 		conduits = conduits->next;
-			
+
 		buf = (gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "valid-synctypes", NULL);
 		if (buf != NULL) {
 			gchar **sync_types = g_strsplit (buf, " ", 0);
